@@ -1,7 +1,7 @@
 
 /*
     xskat - a card game for 1 to 3 players.
-    Copyright (C) 1998  Gunter Gerhardt
+    Copyright (C) 1999  Gunter Gerhardt
 
     This program is free software; you can redistribute it freely.
     Use it at your own risk; there is NO WARRANTY.
@@ -20,6 +20,62 @@
 
 /* Generated stuff follows:
 #############################################################################*/
+VOID irc_log();
+VOID irc_out();
+VOID irc_print();
+VOID irc_printnl();
+char *irc_getline();
+int irc_xinput();
+int irc_match();
+VOID irc_sendnick();
+VOID irc_pr_ss();
+VOID irc_pr_bs();
+VOID irc_pr_sd();
+VOID irc_pr_ramsch();
+VOID irc_pr_sramsch();
+VOID irc_pr_kontra();
+VOID irc_pr_bock();
+VOID irc_pr_resumebock();
+VOID irc_pr_spitze();
+VOID irc_pr_revolution();
+VOID irc_pr_klopfen();
+VOID irc_pr_schenken();
+VOID irc_pr_oldrules();
+VOID irc_pr_bockevents();
+VOID irc_pr_alist();
+VOID irc_pr_start();
+VOID irc_pr_s1();
+VOID irc_sendrules();
+VOID irc_incidx();
+VOID irc_sync();
+VOID irc_sendsync();
+VOID irc_checksync();
+VOID irc_alarm();
+VOID irc_talk();
+char *irc_copyname();
+int irc_senderok();
+VOID irc_histsave();
+VOID irc_sendbtev();
+VOID irc_sendxyev();
+VOID irc_sendsort();
+VOID irc_sendschenken();
+VOID irc_sendloeschen();
+VOID irc_addcmd();
+int irc_getcmd();
+VOID irc_checkhist();
+VOID irc_getrules();
+VOID irc_getserverconf();
+VOID irc_putserverconf();
+VOID irc_putclientconf();
+VOID irc_setpos();
+VOID irc_getclientconf();
+VOID irc_changenick();
+VOID irc_checknick();
+VOID irc_nickchanged();
+VOID irc_msg();
+VOID irc_parse();
+VOID irc_connect();
+VOID irc_init();
 VOID init_null();
 VOID testnull();
 int kleiner_w();
@@ -85,6 +141,7 @@ int sage_kontra();
 int sage_re();
 int testgrand();
 VOID calc_inhand();
+int testhand();
 VOID calc_drueck();
 VOID nextgame();
 VOID save_skat();
@@ -93,6 +150,7 @@ VOID update_list();
 VOID do_grandhand();
 VOID set_prot();
 VOID do_handspiel();
+VOID do_druecken();
 VOID do_handok();
 VOID do_ansagen();
 VOID karobube();
@@ -103,6 +161,7 @@ int higher();
 VOID calc_result();
 VOID get_next();
 VOID save_list();
+VOID setsum();
 VOID modsum();
 VOID read_opt_srpk();
 VOID read_opt();
@@ -134,6 +193,8 @@ int buttern();
 int hatas();
 int schnippeln();
 VOID nichtspitze();
+int spitzefangen();
+int restbeimir();
 VOID m_bvsp();
 VOID m_bmsp();
 VOID m_bhsp();
@@ -151,6 +212,7 @@ int main();
 VOID init_text();
 int langidx();
 VOID info_reiz();
+int trumpf_idx();
 VOID info_spiel();
 VOID info_stich();
 VOID clear_info();
@@ -159,12 +221,25 @@ int ismemb();
 VOID init_di();
 VOID init_dials();
 VOID prverz();
+int ob_disabled();
 VOID hndl_btevent();
+VOID button_press();
+VOID draw_wedge();
+VOID draw_actbtn();
+VOID draw_selpos();
+VOID new_selpos();
+VOID new_actbtn();
+VOID set_selpos();
+VOID del_selpos();
 VOID hndl_events();
+VOID getob_xywhbd();
 VOID create_dial();
+VOID findlastex();
 VOID create_di();
+VOID create_diopt();
 VOID remove_dial();
 VOID remove_di();
+VOID draw_3d();
 VOID draw_dial();
 VOID draw_di();
 VOID refresh();
@@ -183,6 +258,7 @@ VOID di_konre();
 VOID di_ktrnext();
 VOID di_dicht();
 VOID di_weiter();
+VOID di_wiederweiter();
 VOID di_klopfen();
 VOID di_schenken();
 VOID di_geschenkt();
@@ -194,18 +270,22 @@ VOID di_buben();
 VOID di_spiel();
 VOID list_fun();
 VOID di_liste();
+int ger_toupper();
 VOID pformat();
 VOID prot_fun();
 VOID im_skat();
 VOID di_proto();
+VOID di_resultdi();
 VOID di_result();
 VOID di_delres();
 VOID di_options();
 VOID di_copyr();
+VOID di_grafik();
 VOID di_strateg();
 VOID di_varianten();
 VOID di_bockevents();
-VOID di_verzoegerung();
+VOID di_geschwindigkeit();
+VOID di_irc();
 VOID di_menubutton();
 VOID di_wieder();
 VOID change_gc();
@@ -222,8 +302,8 @@ VOID draw_skat();
 VOID home_skat();
 VOID nimm_stich();
 VOID drop_card();
-VOID create_colcards();
-VOID alloc_colors();
+int query_err();
+int closest_col();
 unsigned long get_col();
 VOID calc_desk();
 VOID extractnam();
@@ -232,8 +312,20 @@ VOID invopt();
 VOID nomem();
 VOID finish();
 int ioerr();
+VOID exitus();
+VOID startirc();
 int getdeffn();
 VOID logit();
+int getcode();
+VOID decompgif();
+VOID drawimg();
+VOID create_card();
+VOID xinitwin();
+VOID xinitplayers();
+int closecol();
+VOID find_cardcol();
+VOID card_colors();
+VOID xinitres();
 VOID xinit();
 VOID waitt();
 VOID stdwait();
@@ -242,6 +334,8 @@ VOID putdesk();
 VOID drawcard();
 VOID putcard();
 VOID putback();
+VOID hint_line();
+VOID show_hint();
 VOID putamark();
 VOID putmark();
 VOID remmark();
@@ -249,7 +343,7 @@ VOID movecard();
 VOID homecard();
 VOID givecard();
 VOID initscr();
-VOID nullendscr();
+VOID spielendscr();
 VOID revolutionsort();
 VOID revolutionscr();
 VOID clr_desk();
@@ -266,5 +360,5 @@ int hndl_druecken();
 int hndl_tauschen();
 int hndl_spielen();
 int hndl_nimmstich();
-VOID hndl_button();
+int hndl_button();
 VOID setcurs();
