@@ -1,7 +1,7 @@
 
 /*
     xskat - a card game for 1 to 3 players.
-    Copyright (C) 1998  Gunter Gerhardt
+    Copyright (C) 1999  Gunter Gerhardt
 
     This program is free software; you can redistribute it freely.
     Use it at your own risk; there is NO WARRANTY.
@@ -41,7 +41,7 @@ VOID init_ramsch()
   info_reiz();
   info_spiel();
   for (sn=0;sn<numsp;sn++) {
-    initscr(sn);
+    initscr(sn,1);
   }
   for (sn=0;sn<3;sn++) {
     rstsum[sn]=rstich[sn]=ggdurchm[sn]=0;
@@ -365,13 +365,35 @@ int sn,*s;
 int comp_sramsch(sn)
 int sn;
 {
-  int fb,n,i,j,c,ea;
-  int p[4],t[4],s[4],o[4];
+  int fb,n,i,j,c,ea,bb;
+  int p[4],t[4],s[4],o[4],b[4];
 
   n=unsich_fb(sn,s);
-  if (n<=1) {
-    return ((ramschspiele && klopfen) || playsramsch) &&
-      di_verdoppelt(0,!playsramsch);
+  bb=b[0]=b[1]=b[2]=b[3]=0;
+  for (i=0;i<10;i++) {
+    c=cards[sn*10+i];
+    if ((c&7)==BUBE) bb++,b[c>>3]=1;
+  }
+  if (ramschspiele && klopfen && !playsramsch) {
+    if ((n<=3 && (!n || bb<=1)) ||
+	(n<=2 && (!n || bb<=2))) {
+      return di_verdoppelt(0,1);
+    }
+  }
+  if (playsramsch) {
+    if (sn==left(ausspl)) {
+      if ((n<=3 && !bb) ||
+	  (n==1 && bb<=1 && !b[3]) ||
+	  !n) {
+	return di_verdoppelt(0,0);
+      }
+    }
+    else if ((n==3 && !bb) ||
+	     (n==2 && bb<=1 && !b[3]) ||
+	     (n==1 && bb<=2) ||
+	     !n) {
+      return di_verdoppelt(0,0);
+    }
   }
   if (!playsramsch) return 0;
   for (fb=0;fb<4;fb++) {
@@ -405,6 +427,7 @@ int sn;
   for (i=0;i<10;i++) spcards[i]=cards[sn*10+i];
   spcards[10]=cards[30];
   spcards[11]=cards[31];
+  bb=b[0]=b[1]=b[2]=b[3]=0;
   for (i=0;i<12;i++) {
     c=spcards[i];
     if ((c&7)!=BUBE) {
@@ -412,6 +435,7 @@ int sn;
       t[c>>3]++;
       inhand[c>>3][c&7]=1;
     }
+    else bb++,b[c>>3]=1;
   }
   for (fb=0;fb<4;fb++) {
     for (i=fb+1;i<4;i++) {
@@ -461,8 +485,14 @@ int sn;
       }
     }
   }
-  if (ramschspiele && klopfen && unsich_fb(sn,s)<=1 && !ggdurchm[sn]) {
-    return di_verdoppelt(0,1);
+  if (ramschspiele && klopfen && !ggdurchm[sn]) {
+    n=unsich_fb(sn,s);
+    if ((n<=3 && !bb) ||
+	(n<=2 && (bb<=1 || (bb==2 && !b[3]))) ||
+	(n<=1 && (bb<=2 || (bb==3 && b[0]))) ||
+	!n) {
+      return di_verdoppelt(0,1);
+    }
   }
   return 0;
 }
