@@ -1,7 +1,7 @@
 
 /*
     xskat - a card game for 1 to 3 players.
-    Copyright (C) 1998  Gunter Gerhardt
+    Copyright (C) 1999  Gunter Gerhardt
 
     This program is free software; you can redistribute it freely.
     Use it at your own risk; there is NO WARRANTY.
@@ -10,6 +10,8 @@
 #ifndef XDIAL_H
 #define XDIAL_H
 
+#include "text.h"
+
 #undef EXTERN
 #ifdef XDIAL_C
 #define EXTERN
@@ -26,13 +28,14 @@
 #define OB_BOLD       (1<<5)
 #define OB_UNDERLINED (1<<6)
 #define OB_RIGHT      (1<<7)
+#define OB_DISABLED   (1<<8)
 
-#define TOB(t) ((char *)((t)+OB_NONE+1))
+#define TOB(t) ((tx_typ *)((t)+OB_NONE+1))
 
 typedef struct {
   int spec;
   int x,y,w,h;
-  char *str;
+  tx_typ *str;
   int next;
   Window win;
 } OBJECT;
@@ -40,6 +43,7 @@ typedef struct {
 EXTERN OBJECT *actdial[3];
 EXTERN OBJECT *resdial[3];
 EXTERN int ktrsag,ktrnext,schenknext;
+EXTERN tx_typ stichstr[2][3][3],spielstr[2][3];
 
 EXTERN OBJECT dihand[]
 #ifdef XDIAL_C
@@ -220,7 +224,7 @@ EXTERN OBJECT dispiel[]
 #ifdef XDIAL_C
 =
 {
-  {15,0,0,43,13,OB_NONE,OB_NONE},
+  {16,0,0,43,13,OB_NONE,OB_NONE},
   {OB_CENTERED|OB_UNDERLINED,1,1,41,1,TOB(TX_SPIEL),OB_NONE},
   {OB_BUTTON,2,3,9,1,TOB(TX_KARO),1},
   {OB_BUTTON,12,3,9,1,TOB(TX_HERZ),1},
@@ -234,7 +238,8 @@ EXTERN OBJECT dispiel[]
   {OB_BUTTON,2,9,12,1,TOB(TX_SPITZE),OB_NONE},
   {OB_EXIT,15,9,13,1,TOB(TX_ANSAGEN),OB_NONE},
   {OB_BUTTON,29,9,12,1,TOB(TX_REVOLUTION),-11},
-  {OB_CENTERED,1,11,41,1,OB_NONE,OB_NONE}
+  {OB_EXIT,2,11,5,1,OB_NONE,OB_NONE},
+  {OB_CENTERED,8,11,27,1,OB_NONE,OB_NONE}
 }
 #endif
 ;
@@ -294,16 +299,16 @@ EXTERN OBJECT diansage[]
 #endif
 ;
 
-EXTERN OBJECT dikontra[]
+EXTERN OBJECT dikontra[3][5]
 #ifdef XDIAL_C
 =
-{
+{{
   {5,0,0,24,7,OB_NONE,OB_NONE},
   {OB_CENTERED|OB_UNDERLINED,1,1,22,1,TOB(TX_ANGESAGT_IST),OB_NONE},
   {OB_CENTERED,1,3,22,1,OB_NONE,OB_NONE},
   {OB_EXIT,2,5,9,1,TOB(TX_KONTRA),OB_NONE},
   {OB_EXIT,13,5,9,1,TOB(TX_AHA),OB_NONE}
-}
+}}
 #endif
 ;
 
@@ -320,16 +325,16 @@ EXTERN OBJECT direkontra[]
 #endif
 ;
 
-EXTERN OBJECT dikonre[]
+EXTERN OBJECT dikonre[3][5]
 #ifdef XDIAL_C
 =
-{
+{{
   {5,0,0,24,8,OB_NONE,OB_NONE},
   {OB_CENTERED|OB_UNDERLINED,1,1,22,1,TOB(TX_ANGESAGT_IST),OB_NONE},
   {OB_CENTERED,1,3,22,1,OB_NONE,OB_NONE},
   {OB_CENTERED,1,4,22,1,OB_NONE,OB_NONE},
   {OB_EXIT,7,6,10,1,TOB(TX_AHA),OB_NONE}
-}
+}}
 #endif
 ;
 
@@ -337,21 +342,34 @@ EXTERN OBJECT didicht[]
 #ifdef XDIAL_C
 =
 {
-  {5,0,0,24,7,OB_NONE,OB_NONE},
-  {OB_CENTERED|OB_UNDERLINED,1,1,22,1,TOB(TX_NULL_DICHT_T),OB_NONE},
+  {7,0,0,24,9,OB_NONE,OB_NONE},
+  {OB_CENTERED|OB_UNDERLINED,1,1,22,1,TOB(TX_NULL_DICHT),OB_NONE},
   {OB_CENTERED,1,3,22,1,TOB(TX_KARTEN_AUFDECKEN),OB_NONE},
-  {OB_EXIT,5,5,6,1,TOB(TX_JA),OB_NONE},
-  {OB_EXIT,13,5,6,1,TOB(TX_NEIN),OB_NONE}
+  {OB_EXIT,4,5,7,1,TOB(TX_JA),OB_NONE},
+  {OB_EXIT,13,5,7,1,TOB(TX_NEIN),OB_NONE},
+  {OB_EXIT,4,7,7,1,TOB(TX_IMMER),OB_NONE},
+  {OB_EXIT,13,7,7,1,TOB(TX_NIE),OB_NONE}
 }
 #endif
 ;
 
-EXTERN OBJECT diweiter[]
+EXTERN OBJECT diweiter[3][2]
+#ifdef XDIAL_C
+=
+{{
+  {2,0,0,14,3,OB_NONE,OB_NONE},
+  {OB_EXIT,2,1,10,1,TOB(TX_WEITER),OB_NONE}
+}}
+#endif
+;
+
+EXTERN OBJECT diwiederweiter[]
 #ifdef XDIAL_C
 =
 {
-  {2,0,0,14,3,OB_NONE,OB_NONE},
-  {OB_EXIT,2,1,10,1,TOB(TX_WEITER),OB_NONE}
+  {3,0,0,34,3,OB_NONE,OB_NONE},
+  {OB_EXIT,2,1,14,1,TOB(TX_WIEDER),OB_NONE},
+  {OB_EXIT,18,1,14,1,TOB(TX_WEITER),OB_NONE}
 }
 #endif
 ;
@@ -484,11 +502,11 @@ EXTERN OBJECT diproto[3][50]
 #endif
 ;
 
-EXTERN OBJECT diliste[3][62]
+EXTERN OBJECT diliste[3][63]
 #ifdef XDIAL_C
 =
 {{
-  {62,0,0,38,21,OB_NONE,OB_NONE},
+  {63,0,0,38,21,OB_NONE,OB_NONE},
   {OB_CENTERED|OB_UNDERLINED,1,1,36,1,TOB(TX_SPIELLISTE_T),OB_NONE},
   {OB_CENTERED,2,3,10,1,OB_NONE,OB_NONE},
   {OB_CENTERED,12,3,10,1,OB_NONE,OB_NONE},
@@ -548,7 +566,8 @@ EXTERN OBJECT diliste[3][62]
   {OB_RIGHT,19,17,10,1,OB_NONE,OB_NONE},
   {OB_RIGHT,29,17,7,1,OB_NONE,OB_NONE},
   {OB_EXIT,2,19,8,1,OB_NONE,OB_NONE},
-  {OB_EXIT,13,19,12,1,TOB(TX_WEITER),OB_NONE},
+  {OB_EXIT,11,19,5,1,OB_NONE,OB_NONE},
+  {OB_EXIT,17,19,10,1,TOB(TX_WEITER),OB_NONE},
   {OB_EXIT,28,19,8,1,OB_NONE,OB_NONE}
 }}
 #endif
@@ -584,61 +603,86 @@ EXTERN OBJECT dioptions[3][22]
 #endif
 ;
 
-EXTERN OBJECT dicopyr[3][9]
+EXTERN OBJECT dicopyr[3][11]
 #ifdef XDIAL_C
 =
 {{
-  {9,0,0,40,13,OB_NONE,OB_NONE},
+  {11,0,0,40,16,OB_NONE,OB_NONE},
   {OB_CENTERED|OB_UNDERLINED,1,1,38,1,TOB(TX_XSKAT),OB_NONE},
   {OB_CENTERED,1,3,38,1,TOB(TX_COPYRIGHT),OB_NONE},
   {OB_CENTERED,1,4,38,1,TOB(TX_EMAIL),OB_NONE},
-  {OB_CENTERED,1,6,38,1,TOB(TX_FR1),OB_NONE},
-  {OB_CENTERED,1,7,38,1,TOB(TX_FR2),OB_NONE},
-  {OB_CENTERED,1,8,38,1,TOB(TX_FR3),OB_NONE},
-  {OB_CENTERED,1,9,38,1,TOB(TX_FR4),OB_NONE},
-  {OB_EXIT,13,11,14,1,TOB(TX_WEITER),OB_NONE}
+  {OB_CENTERED,1,6,38,1,TOB(TX_HOMEPAGE),OB_NONE},
+  {OB_CENTERED,1,7,38,1,TOB(TX_URL),OB_NONE},
+  {OB_CENTERED,1,9,38,1,TOB(TX_FR1),OB_NONE},
+  {OB_CENTERED,1,10,38,1,TOB(TX_FR2),OB_NONE},
+  {OB_CENTERED,1,11,38,1,TOB(TX_FR3),OB_NONE},
+  {OB_CENTERED,1,12,38,1,TOB(TX_FR4),OB_NONE},
+  {OB_EXIT,13,14,14,1,TOB(TX_WEITER),OB_NONE}
 }}
 #endif
 ;
 
-EXTERN OBJECT distrateg[3][25]
+EXTERN OBJECT digrafik[3][11]
 #ifdef XDIAL_C
 =
 {{
-  {25,0,0,38,9,OB_NONE,OB_NONE},
-  {OB_CENTERED|OB_UNDERLINED,1,1,36,1,TOB(TX_STRATEGIE),OB_NONE},
-  {OB_NONE,10,3,10,1,TOB(TX_PASSE_K),OB_NONE},
-  {OB_RIGHT,27,3,10,1,TOB(TX_SAGE18),OB_NONE},
-  {OB_NONE,1,4,9,1,TOB(TX_LINKS),OB_NONE},
-  {OB_BUTTON,10,4,3,1,OB_NONE,1},
-  {OB_BUTTON,13,4,3,1,OB_NONE,1},
-  {OB_BUTTON,16,4,3,1,OB_NONE,1},
-  {OB_BUTTON,19,4,3,1,OB_NONE,1},
-  {OB_BUTTON,22,4,3,1,OB_NONE,1},
-  {OB_BUTTON,25,4,3,1,OB_NONE,1},
-  {OB_BUTTON,28,4,3,1,OB_NONE,1},
-  {OB_BUTTON,31,4,3,1,OB_NONE,1},
-  {OB_BUTTON,34,4,3,1,OB_NONE,-8},
-  {OB_NONE,1,5,9,1,TOB(TX_RECHTS),OB_NONE},
-  {OB_BUTTON,10,5,3,1,OB_NONE,1},
-  {OB_BUTTON,13,5,3,1,OB_NONE,1},
-  {OB_BUTTON,16,5,3,1,OB_NONE,1},
-  {OB_BUTTON,19,5,3,1,OB_NONE,1},
-  {OB_BUTTON,22,5,3,1,OB_NONE,1},
-  {OB_BUTTON,25,5,3,1,OB_NONE,1},
-  {OB_BUTTON,28,5,3,1,OB_NONE,1},
-  {OB_BUTTON,31,5,3,1,OB_NONE,1},
-  {OB_BUTTON,34,5,3,1,OB_NONE,-8},
-  {OB_EXIT,12,7,14,1,TOB(TX_WEITER),OB_NONE}
+  {11,0,0,40,11,OB_NONE,OB_NONE},
+  {OB_CENTERED|OB_UNDERLINED,1,1,38,1,TOB(TX_GRAFIK_UND_TEXT_T),OB_NONE},
+  {OB_NONE,2,3,10,1,TOB(TX_BLATT),OB_NONE},
+  {OB_EXIT,2,4,23,1,TOB(TX_FRANZOESISCH),1},
+  {OB_EXIT,2,5,23,1,TOB(TX_FRANZOESISCH_4_FARBEN),1},
+  {OB_EXIT,2,6,23,1,TOB(TX_DEUTSCH),1},
+  {OB_EXIT,2,7,23,1,TOB(TX_DEUTSCH_4_FARBEN),-3},
+  {OB_NONE,28,3,10,1,TOB(TX_SPRACHE),OB_NONE},
+  {OB_EXIT,28,4,10,1,TOB(TX_GERMAN),1},
+  {OB_EXIT,28,5,10,1,TOB(TX_ENGLISH),-1},
+  {OB_EXIT,13,9,14,1,TOB(TX_WEITER),OB_NONE}
 }}
 #endif
 ;
 
-EXTERN OBJECT divarianten[3][34]
+EXTERN OBJECT distrateg[3][29]
 #ifdef XDIAL_C
 =
 {{
-  {34,0,0,42,15,OB_NONE,OB_NONE},
+  {29,0,0,40,11,OB_NONE,OB_NONE},
+  {OB_CENTERED|OB_UNDERLINED,1,1,38,1,TOB(TX_COMPUTER_T),OB_NONE},
+  {OB_NONE,1,3,10,1,TOB(TX_STRATEGIE),OB_NONE},
+  {OB_NONE,12,3,10,1,TOB(TX_PASSE_K),OB_NONE},
+  {OB_RIGHT,29,3,10,1,TOB(TX_SAGE18),OB_NONE},
+  {OB_NONE,2,4,9,1,TOB(TX_LINKS),OB_NONE},
+  {OB_BUTTON,12,4,3,1,OB_NONE,1},
+  {OB_BUTTON,15,4,3,1,OB_NONE,1},
+  {OB_BUTTON,18,4,3,1,OB_NONE,1},
+  {OB_BUTTON,21,4,3,1,OB_NONE,1},
+  {OB_BUTTON,24,4,3,1,OB_NONE,1},
+  {OB_BUTTON,27,4,3,1,OB_NONE,1},
+  {OB_BUTTON,30,4,3,1,OB_NONE,1},
+  {OB_BUTTON,33,4,3,1,OB_NONE,1},
+  {OB_BUTTON,36,4,3,1,OB_NONE,-8},
+  {OB_NONE,2,5,9,1,TOB(TX_RECHTS),OB_NONE},
+  {OB_BUTTON,12,5,3,1,OB_NONE,1},
+  {OB_BUTTON,15,5,3,1,OB_NONE,1},
+  {OB_BUTTON,18,5,3,1,OB_NONE,1},
+  {OB_BUTTON,21,5,3,1,OB_NONE,1},
+  {OB_BUTTON,24,5,3,1,OB_NONE,1},
+  {OB_BUTTON,27,5,3,1,OB_NONE,1},
+  {OB_BUTTON,30,5,3,1,OB_NONE,1},
+  {OB_BUTTON,33,5,3,1,OB_NONE,1},
+  {OB_BUTTON,36,5,3,1,OB_NONE,-8},
+  {OB_NONE,1,7,10,1,TOB(TX_VORSCHLAEGE),OB_NONE},
+  {OB_BUTTON,12,7,8,1,TOB(TX_NEIN),1},
+  {OB_BUTTON,20,7,8,1,TOB(TX_JA),-1},
+  {OB_EXIT,13,9,14,1,TOB(TX_WEITER),OB_NONE}
+}}
+#endif
+;
+
+EXTERN OBJECT divarianten[3][37]
+#ifdef XDIAL_C
+=
+{{
+  {37,0,0,42,16,OB_NONE,OB_NONE},
   {OB_CENTERED|OB_UNDERLINED,1,1,40,1,TOB(TX_VARIANTEN),OB_NONE},
   {OB_NONE,1,3,20,1,TOB(TX_RAMSCH_SPIELEN),OB_NONE},
   {OB_BUTTON,17,3,7,1,TOB(TX_NEIN),1},
@@ -671,7 +715,10 @@ EXTERN OBJECT divarianten[3][34]
   {OB_NONE,1,11,18,1,TOB(TX_SCHENKEN),OB_NONE},
   {OB_BUTTON,17,11,7,1,TOB(TX_NEIN),1},
   {OB_BUTTON,24,11,7,1,TOB(TX_JA),-1},
-  {OB_EXIT,14,13,14,1,TOB(TX_WEITER),OB_NONE}
+  {OB_NONE,1,12,18,1,TOB(TX_ALTE_REGELN),OB_NONE},
+  {OB_BUTTON,17,12,7,1,TOB(TX_NEIN),1},
+  {OB_BUTTON,24,12,7,1,TOB(TX_JA),-1},
+  {OB_EXIT,14,14,14,1,TOB(TX_WEITER),OB_NONE}
 }}
 #endif
 ;
@@ -695,33 +742,52 @@ EXTERN OBJECT dibockevents[3][11]
 #endif
 ;
 
-EXTERN OBJECT diverzoegerung[3][14]
+EXTERN OBJECT digeschwindigkeit[3][18]
 #ifdef XDIAL_C
 =
 {{
-  {14,0,0,27,12,OB_NONE,OB_NONE},
-  {OB_CENTERED|OB_UNDERLINED,1,1,25,1,TOB(TX_VERZOEGERUNG),OB_NONE},
-  {OB_CENTERED,1,3,25,1,TOB(TX_NIMM_STICH_NACH),OB_NONE},
-  {OB_CENTERED,1,4,25,1,OB_NONE,OB_NONE},
-  {OB_EXIT,2,5,3,1,OB_NONE,OB_NONE},
-  {OB_EXIT,6,5,3,1,OB_NONE,OB_NONE},
-  {OB_EXIT,10,5,3,1,OB_NONE,OB_NONE},
-  {OB_EXIT,14,5,3,1,OB_NONE,OB_NONE},
-  {OB_EXIT,18,5,3,1,OB_NONE,OB_NONE},
-  {OB_EXIT,22,5,3,1,OB_NONE,OB_NONE},
-  {OB_CENTERED,1,7,25,1,TOB(TX_GEBEN),OB_NONE},
-  {OB_BUTTON,2,8,11,1,TOB(TX_SCHNELL),1},
-  {OB_BUTTON,14,8,11,1,TOB(TX_LANGSAM),-1},
-  {OB_EXIT,7,10,13,1,TOB(TX_WEITER),OB_NONE}
+  {18,0,0,33,15,OB_NONE,OB_NONE},
+  {OB_CENTERED|OB_UNDERLINED,1,1,31,1,TOB(TX_GESCHWINDIGKEIT),OB_NONE},
+  {OB_CENTERED,1,3,31,1,TOB(TX_NIMM_STICH_NACH),OB_NONE},
+  {OB_CENTERED,1,4,31,1,OB_NONE,OB_NONE},
+  {OB_EXIT,2,5,4,1,OB_NONE,OB_NONE},
+  {OB_EXIT,7,5,4,1,OB_NONE,OB_NONE},
+  {OB_EXIT,12,5,4,1,OB_NONE,OB_NONE},
+  {OB_EXIT,17,5,4,1,OB_NONE,OB_NONE},
+  {OB_EXIT,22,5,4,1,OB_NONE,OB_NONE},
+  {OB_EXIT,27,5,4,1,OB_NONE,OB_NONE},
+  {OB_CENTERED,1,7,31,1,TOB(TX_GEBEN),OB_NONE},
+  {OB_BUTTON,2,8,14,1,TOB(TX_SCHNELL),1},
+  {OB_BUTTON,17,8,14,1,TOB(TX_LANGSAM),-1},
+  {OB_CENTERED,1,10,31,1,TOB(TX_ABKUERZUNG),OB_NONE},
+  {OB_BUTTON,2,11,9,1,TOB(TX_NIE),1},
+  {OB_BUTTON,12,11,9,1,TOB(TX_FRAGEN),1},
+  {OB_BUTTON,22,11,9,1,TOB(TX_IMMER),-2},
+  {OB_EXIT,10,13,13,1,TOB(TX_WEITER),OB_NONE}
 }}
 #endif
 ;
 
-EXTERN OBJECT dimenubutton[3][9]
+EXTERN OBJECT diirc[]
+#ifdef XDIAL_C
+=
+{
+  {7,0,0,38,12,OB_NONE,OB_NONE},
+  {OB_CENTERED|OB_UNDERLINED,1,1,36,1,TOB(TX_IRC_T),OB_NONE},
+  {OB_CENTERED,1,3,36,1,TOB(TX_IRC_VERBINDUNG_HERSTELLEN),OB_NONE},
+  {OB_EXIT,2,5,34,1,OB_NONE,OB_NONE},
+  {OB_CENTERED,1,7,36,1,TOB(TX_IRC_KONFIGURATION_SIEHE),OB_NONE},
+  {OB_CENTERED,1,8,36,1,TOB(TX_IRC_MAN_XSKAT),OB_NONE},
+  {OB_EXIT,12,10,14,1,TOB(TX_WEITER),OB_NONE}
+}
+#endif
+;
+
+EXTERN OBJECT dimenubutton[3][10]
 #ifdef XDIAL_C
 =
 {{
-  {9,0,0,38,7,OB_NONE,OB_NONE},
+  {10,0,0,38,9,OB_NONE,OB_NONE},
   {OB_CENTERED|OB_UNDERLINED,1,1,36,1,TOB(TX_MENU_BUTTON),OB_NONE},
   {OB_BUTTON,3,3,7,1,TOB(TX_JEDER),1},
   {OB_BUTTON,11,3,4,1,OB_NONE,1},
@@ -729,7 +795,8 @@ EXTERN OBJECT dimenubutton[3][9]
   {OB_BUTTON,21,3,4,1,OB_NONE,1},
   {OB_BUTTON,26,3,4,1,OB_NONE,1},
   {OB_BUTTON,31,3,4,1,OB_NONE,-5},
-  {OB_EXIT,12,5,14,1,TOB(TX_WEITER),OB_NONE}
+  {OB_CENTERED,1,5,36,1,TOB(TX_UND_ESC_F1),OB_NONE},
+  {OB_EXIT,12,7,14,1,TOB(TX_WEITER),OB_NONE}
 }}
 #endif
 ;
